==> krita-debuginfo-3.3.2.1-1.tar.xz: usr/src/debug/krita-3.3.2.1-1/plugins/tools/tool_transform2/qrc_tool_transform.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.2.1-1.i686/src/krita-3.3.2.1/plugins/tools/tool_transform2/shear_cursor.png
  0x0,0x0,0x0,0x9f,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x2,0x3,0x0,0x0,0x0,0xb9,0xda,0x84,0xa8,
  0x0,0x0,0x0,0x9,0x50,0x4c,0x54,0x45,0x0,0x0,0x3,0x0,0x0,0x0,0xff,0xff,
  0xff,0xb2,0x35,0xd5,0x4f,0x0,0x0,0x0,0x1,0x74,0x52,0x4e,0x53,0x0,0x40,0xe6,
  0xd8,0x66,0x0,0x0,0x0,0x44,0x49,0x44,0x41,0x54,0x8,0xd7,0x63,0x60,0x50,0x60,
  0x0,0x83,0x19,0x60,0x92,0x29,0x2,0x4c,0x71,0x46,0xad,0x5a,0xd5,0xc0,0xc0,0xa0,
  0x1a,0x1a,0x1a,0xea,0x0,0xe4,0x45,0x30,0x30,0x35,0x80,0xe5,0x98,0x12,0xc0,0x2a,
  0xc1,0xaa,0xb4,0x56,0xad,0xa,0x3,0x52,0xa2,0x40,0x35,0xd,0x60,0xad,0x61,0xc8,
  0x26,0x80,0x55,0x2,0x41,0x3,0x3,0xb9,0x0,0x0,0x19,0x9b,0xc,0x3b,0xf0,0x8b,
  0x51,0x32,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
    // /usr/src/ports/krita/krita-3.3.2.1-1.i686/src/krita-3.3.2.1/plugins/tools/tool_transform2/rotate_cursor.xpm
  0x0,0x0,0x0,0xc6,
  0x0,
  0x0,0x2,0xa9,0x78,0x9c,0xbd,0x91,0xcd,0xa,0xc2,0x30,0xc,0xc7,0xef,0x7d,0x8a,
  0xd0,0xdc,0x86,0x38,0x1d,0xde,0xc4,0x47,0x70,0x78,0x14,0x44,0x24,0x2b,0x13,0xbd,
  0x38,0xe8,0xe6,0x49,0x7c,0x77,0x93,0xb6,0xae,0xdb,0x3a,0xf0,0xe6,0x9f,0xb1,0x25,
  0xf9,0x35,0xcb,0x47,0xf3,0xc,0x8e,0x87,0x3d,0x64,0xb9,0x6a,0x3b,0xea,0xee,0x6,
  0xcc,0x8d,0x2c,0x64,0xb6,0x61,0xaf,0xbe,0x98,0xa7,0x6d,0x1b,0x7b,0x3a,0xef,0x5e,
  0x4a,0x17,0x5,0xf0,0xb3,0x81,0xb5,0x5e,0x28,0x5d,0x81,0x81,0xb2,0x79,0xd4,0x62,
  0x2f,0x7,0x36,0xb1,0x8d,0x2b,0x27,0x71,0x51,0xdc,0xab,0x93,0x3b,0x39,0xab,0xdf,
  0x4,0xd1,0xbd,0xd0,0x7d,0xc7,0x84,0x38,0x48,0xa2,0x2f,0x8b,0x84,0x55,0x89,0x98,
  0x25,0xc4,0x47,0x98,0x61,0x92,0x13,0xfe,0xe3,0x51,0xec,0x20,0x56,0xf7,0x59,0xb3,
  0x5d,0xf,0x8,0x17,0x4e,0x90,0x27,0x48,0xff,0x21,0x53,0x24,0x1d,0x25,0xa4,0x1f,
  0x2c,0xee,0x20,0xa0,0x7e,0x19,0xfd,0xa4,0x48,0x61,0x28,0x9c,0x12,0x89,0xc8,0xaa,
  0xd3,0x1c,0xa9,0x10,0xee,0x7,0xa7,0x24,0xde,0x29,0x26,0x64,0x24,0xfd,0xde,0xaa,
  0xf,0x35,0x1,0x8d,0x5a,
  
};

static const unsigned char qt_resource_name[] = {
  // shear_cursor.png
  0x0,0x10,
  0xb,0x70,0x74,0x87,
  0x0,0x73,
  0x0,0x68,0x0,0x65,0x0,0x61,0x0,0x72,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
    // rotate_cursor.xpm
  0x0,0x11,
  0xe,0xeb,0xac,0x6d,
  0x0,0x72,
  0x0,0x6f,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x65,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x78,0x0,0x70,0x0,0x6d,
  
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/shear_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x7c,0x2c,0x70,0x40,
  // :/rotate_cursor.xpm
  0x0,0x0,0x0,0x26,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xa3,
0x0,0x0,0x1,0x5f,0x7c,0x2c,0x70,0x40,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_transform)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_transform)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_transform)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_transform)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_transform)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_transform)(); }
   } dummy;
}

==> krita-debuginfo-3.3.3-1.tar.xz: usr/src/debug/krita-3.3.3-1/plugins/tools/tool_transform2/qrc_tool_transform.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.3-1.x86_64/src/krita-3.3.3/plugins/tools/tool_transform2/shear_cursor.png
  0x0,0x0,0x0,0x9f,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x2,0x3,0x0,0x0,0x0,0xb9,0xda,0x84,0xa8,
  0x0,0x0,0x0,0x9,0x50,0x4c,0x54,0x45,0x0,0x0,0x3,0x0,0x0,0x0,0xff,0xff,
  0xff,0xb2,0x35,0xd5,0x4f,0x0,0x0,0x0,0x1,0x74,0x52,0x4e,0x53,0x0,0x40,0xe6,
  0xd8,0x66,0x0,0x0,0x0,0x44,0x49,0x44,0x41,0x54,0x8,0xd7,0x63,0x60,0x50,0x60,
  0x0,0x83,0x19,0x60,0x92,0x29,0x2,0x4c,0x71,0x46,0xad,0x5a,0xd5,0xc0,0xc0,0xa0,
  0x1a,0x1a,0x1a,0xea,0x0,0xe4,0x45,0x30,0x30,0x35,0x80,0xe5,0x98,0x12,0xc0,0x2a,
  0xc1,0xaa,0xb4,0x56,0xad,0xa,0x3,0x52,0xa2,0x40,0x35,0xd,0x60,0xad,0x61,0xc8,
  0x26,0x80,0x55,0x2,0x41,0x3,0x3,0xb9,0x0,0x0,0x19,0x9b,0xc,0x3b,0xf0,0x8b,
  0x51,0x32,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
    // /usr/src/ports/krita/krita-3.3.3-1.x86_64/src/krita-3.3.3/plugins/tools/tool_transform2/rotate_cursor.xpm
  0x0,0x0,0x0,0xc6,
  0x0,
  0x0,0x2,0xa9,0x78,0x9c,0xbd,0x91,0xcd,0xa,0xc2,0x30,0xc,0xc7,0xef,0x7d,0x8a,
  0xd0,0xdc,0x86,0x38,0x1d,0xde,0xc4,0x47,0x70,0x78,0x14,0x44,0x24,0x2b,0x13,0xbd,
  0x38,0xe8,0xe6,0x49,0x7c,0x77,0x93,0xb6,0xae,0xdb,0x3a,0xf0,0xe6,0x9f,0xb1,0x25,
  0xf9,0x35,0xcb,0x47,0xf3,0xc,0x8e,0x87,0x3d,0x64,0xb9,0x6a,0x3b,0xea,0xee,0x6,
  0xcc,0x8d,0x2c,0x64,0xb6,0x61,0xaf,0xbe,0x98,0xa7,0x6d,0x1b,0x7b,0x3a,0xef,0x5e,
  0x4a,0x17,0x5,0xf0,0xb3,0x81,0xb5,0x5e,0x28,0x5d,0x81,0x81,0xb2,0x79,0xd4,0x62,
  0x2f,0x7,0x36,0xb1,0x8d,0x2b,0x27,0x71,0x51,0xdc,0xab,0x93,0x3b,0x39,0xab,0xdf,
  0x4,0xd1,0xbd,0xd0,0x7d,0xc7,0x84,0x38,0x48,0xa2,0x2f,0x8b,0x84,0x55,0x89,0x98,
  0x25,0xc4,0x47,0x98,0x61,0x92,0x13,0xfe,0xe3,0x51,0xec,0x20,0x56,0xf7,0x59,0xb3,
  0x5d,0xf,0x8,0x17,0x4e,0x90,0x27,0x48,0xff,0x21,0x53,0x24,0x1d,0x25,0xa4,0x1f,
  0x2c,0xee,0x20,0xa0,0x7e,0x19,0xfd,0xa4,0x48,0x61,0x28,0x9c,0x12,0x89,0xc8,0xaa,
  0xd3,0x1c,0xa9,0x10,0xee,0x7,0xa7,0x24,0xde,0x29,0x26,0x64,0x24,0xfd,0xde,0xaa,
  0xf,0x35,0x1,0x8d,0x5a,
  
};

static const unsigned char qt_resource_name[] = {
  // shear_cursor.png
  0x0,0x10,
  0xb,0x70,0x74,0x87,
  0x0,0x73,
  0x0,0x68,0x0,0x65,0x0,0x61,0x0,0x72,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
    // rotate_cursor.xpm
  0x0,0x11,
  0xe,0xeb,0xac,0x6d,
  0x0,0x72,
  0x0,0x6f,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x65,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x78,0x0,0x70,0x0,0x6d,
  
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/shear_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x60,0xd5,0x9a,0x8d,0xa0,
  // :/rotate_cursor.xpm
  0x0,0x0,0x0,0x26,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xa3,
0x0,0x0,0x1,0x60,0xd5,0x9a,0x8d,0xa0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_transform)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_transform)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_transform)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_transform)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_transform)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_transform)(); }
   } dummy;
}
